var annotated_dup =
[
    [ "tvg", null, [
      [ "Point", "structtvg_1_1Point.html", null ],
      [ "Matrix", "structtvg_1_1Matrix.html", null ],
      [ "Paint", "classtvg_1_1Paint.html", "classtvg_1_1Paint" ],
      [ "Fill", "classtvg_1_1Fill.html", "classtvg_1_1Fill" ],
      [ "Canvas", "classtvg_1_1Canvas.html", "classtvg_1_1Canvas" ],
      [ "LinearGradient", "classtvg_1_1LinearGradient.html", "classtvg_1_1LinearGradient" ],
      [ "RadialGradient", "classtvg_1_1RadialGradient.html", "classtvg_1_1RadialGradient" ],
      [ "Shape", "classtvg_1_1Shape.html", "classtvg_1_1Shape" ],
      [ "Picture", "classtvg_1_1Picture.html", "classtvg_1_1Picture" ],
      [ "Scene", "classtvg_1_1Scene.html", "classtvg_1_1Scene" ],
      [ "Text", "classtvg_1_1Text.html", "classtvg_1_1Text" ],
      [ "SwCanvas", "classtvg_1_1SwCanvas.html", "classtvg_1_1SwCanvas" ],
      [ "GlCanvas", "classtvg_1_1GlCanvas.html", "classtvg_1_1GlCanvas" ],
      [ "WgCanvas", "classtvg_1_1WgCanvas.html", "classtvg_1_1WgCanvas" ],
      [ "Initializer", "classtvg_1_1Initializer.html", null ],
      [ "Animation", "classtvg_1_1Animation.html", "classtvg_1_1Animation" ],
      [ "Saver", "classtvg_1_1Saver.html", "classtvg_1_1Saver" ],
      [ "Accessor", "classtvg_1_1Accessor.html", "classtvg_1_1Accessor" ]
    ] ]
];